@@ -8,6 +8,7 @@
 #import "LhaArchive.h"
 #import "LzxArchive.h"
 #import "GzipArchive.h"
+#import "SevenZipArchive.h"
 #import "PreferencesController.h"
 #import "ArchiveService.h"
 
@@ -24,6 +25,7 @@
 	[ZipArchive class];
 	[LzxArchive class];
 	[GzipArchive class];
+	[SevenZipArchive class];
 }
 
 //------------------------------------------------------------------------------
