@@ -49,9 +49,11 @@ enum
 + (BOOL)hasRatio;
 + (BOOL)canExtractWithoutFullPath;
 + (NSString *)archiveType;
++ (NSData *)magicBytes;
 
 + (void)registerFileExtension:(NSString *)extension forArchiveClass:(Class)clazz;
 + (Class)classForFileExtension:(NSString *)fileExtension;
 + (NSArray *)allFileExtensions;
++ (NSArray *)allArchivers;
 
 @end
