@@ -48,6 +48,14 @@ static NSMutableDictionary *_fileExtMappings = nil;
 	return [_fileExtMappings allKeys];
 }
 
+/**
+ * Returns an NSArray containing all archiver classes that are currently registered.
+ */
++ (NSArray *)allArchivers;
+{
+	return [_fileExtMappings allValues];
+}
+
 /**
  * Returns YES if this kind of archives contains information about the compression ratio of
  * the archive, else NO.
@@ -66,6 +74,15 @@ static NSMutableDictionary *_fileExtMappings = nil;
 	return YES;
 }
 
+/**
+ * Returns an NSData that can be compared against the first 4 bytes of the file to
+ * determine the file type. This implementation returns nil.
+ */
++ (NSData *)magicBytes
+{
+	return nil;
+}
+
 + (Archive *)newWithPath:(NSString *)path
 {
     NSParameterAssert(path != nil);
