@@ -2,6 +2,7 @@
 
 #define PREF_KEY_TAR @"TarExecutable"
 #define PREF_KEY_ZIP @"ZipExecutable"
+#define PREF_KEY_SEVEN_ZIP @"7ZipExecutable"
 #define PREF_KEY_RAR @"RarExecutable"
 #define PREF_KEY_LHA @"LhaExecutable"
 #define PREF_KEY_LZX @"LzxExecutable"
@@ -23,6 +24,7 @@
  */
 + (NSString *)tarExecutable;
 + (NSString *)zipExecutable;
++ (NSString *)sevenZipExecutable;
 + (NSString *)rarExecutable;
 + (NSString *)lhaExecutable;
 + (NSString *)lzxExecutable;
@@ -34,6 +36,7 @@
  */
 + (void)setTarExecutable:(NSString *)newTar;
 + (void)setZipExecutable:(NSString *)newZip;
++ (void)setSevenZipExecutable:(NSString *)new7zip;
 + (void)setRarExecutable:(NSString *)newRar;
 + (void)setLhaExecutable:(NSString *)newLha;
 + (void)setLzxExecutable:(NSString *)newLzx;
