@@ -6,6 +6,7 @@
 #import "RarTestCase.h"
 #import "PreferencesTestCase.h"
 #import "LhaTestCase.h"
+#import "SevenZipTestCase.h"
 
 @implementation AllTests : NSObject
 
@@ -17,6 +18,7 @@
 	[suite addTest:[TestSuite suiteWithClass:[TarTestCase class]]];
 	[suite addTest:[TestSuite suiteWithClass:[RarTestCase class]]];
 	[suite addTest:[TestSuite suiteWithClass:[LhaTestCase class]]];
+	[suite addTest:[TestSuite suiteWithClass:[SevenZipTestCase class]]];
     
     return suite;
 }
