@@ -18,6 +18,9 @@
 - (void)setArchive:(Archive *)archive;
 - (void)openFile:(NSString *)file withDefaultApp:(NSString *)defaultApp;
 - (Class)archiveClassForFile:(NSString *)filename;
+- (Class)archiveClassByFileExtension:(NSString *)path;
+- (Class)archiveClassByFileContents:(NSString *)path;
+- (BOOL)createUnarchiveDestinationIfNecessary:(NSString *)path;
 @end
 
 @implementation ZipperDocument : GSMarkupDocument
@@ -81,6 +84,34 @@
 	Class archiveClass = nil;
 
 	archiveClass = [self archiveClassForFile:path];
+	NSAssert1(archiveClass != nil, 
+		@"No archive class registered for '%@'. This should not happen", path);	
+	if ([archiveClass executableDoesExist] == NO)
+	{
+		// ouch, no executable set (yet)
+		NSString *message;
+		PreferencesController *prefsController;
+	
+		message = [NSString stringWithFormat:
+			@"Missing unarchiver for file \"%@\". Please provide a value!", path];
+		NSRunAlertPanel(@"Error in Preferences", message, nil, nil, nil);
+				
+		// bring up the prefs panel
+		prefsController = [[PreferencesController alloc] init];
+		[prefsController showPreferencesPanel];
+		
+		// invoke recursively as the unarchiver should have been set in prefs by now
+		if ([archiveClass executableDoesExist])
+		{
+			return [self openArchiveWithPath:path];
+		}
+		else
+		{
+			// no archiver executable set via prefs, give up
+			return NO;
+		} 
+	}
+	
 	if ([archiveClass hasRatio])
 	{
 		[self addRatioColumn];
@@ -98,6 +129,18 @@
 }
 
 - (Class)archiveClassForFile:(NSString *)path
+{
+	Class archiveClass;
+	
+	archiveClass = [self archiveClassByFileContents:path];
+	if (archiveClass == nil)
+	{
+		archiveClass = [self archiveClassByFileExtension:path];
+	}
+	return archiveClass;
+}
+
+- (Class)archiveClassByFileExtension:(NSString *)path
 {
 	NSString *extension, *secondExtension;
 	Class archiveClass = nil;
@@ -127,31 +170,39 @@
 			
 			// try only the last extension
 			archiveClass = [Archive classForFileExtension:extension];
-			NSAssert1(archiveClass != nil, 
-				@"No archive class registered for '%@'. This should not happen", extension);	
-		}
-		
-
-		if ([archiveClass executableDoesExist] == NO)
-		{
-			// ouch, no executable set (yet)
-			NSString *message;
-			PreferencesController *prefsController;
-	
-			message = [NSString stringWithFormat:
-				@"Missing unarchiver for file extension \"%@\". Please provide a value!", fullExtension];
-			NSRunAlertPanel(@"Error in Preferences", message, nil, nil, nil);
-				
-			// bring up the prefs panel
-			prefsController = [[PreferencesController alloc] init];
-			[prefsController setArchiveForRequiredType:archiveClass];
-			[prefsController showPreferencesPanel];
 		}
 	}
 
 	return archiveClass;	
 }
 
+/*"
+ * Peek inside <code>path</code> to determine file type. This is necessary as some file extensions
+ * are ambiguous, e.g. .rar files can either be Java resource archives or rar-packaged files 
+ */
+- (Class)archiveClassByFileContents:(NSString *)path
+{
+	NSFileHandle *fileHandle;
+	NSData *data, *headerData;
+	NSEnumerator *archiverEnum;
+	Class archiverClass;
+	
+	fileHandle = [NSFileHandle fileHandleForReadingAtPath:path];
+	data = [fileHandle readDataOfLength:4];
+	
+	archiverEnum = [[Archive allArchivers] objectEnumerator];
+	while ((archiverClass = [archiverEnum nextObject]) != nil)
+	{
+		headerData = [archiverClass magicBytes];
+		if ((headerData != nil) && [headerData isEqualToData:data])
+		{
+			return archiverClass;
+		}
+	}
+		
+	return nil;
+}
+
 //-----------------------------------------------------------------------------
 // validating the UI
 //-----------------------------------------------------------------------------
@@ -201,6 +252,7 @@
 	}
 
 	openPanel = [NSOpenPanel openPanel];
+//	[openPanel setDelegate:self];
 	[openPanel setTitle:@"Extract to"];
 	[openPanel setCanChooseFiles:NO];
 	[openPanel setCanChooseDirectories:YES];
@@ -210,6 +262,13 @@
 	{
 		NSString *message;
 		NSString *path = [openPanel directory];
+NSLog(@"path: %@", path);
+
+		// make sure the destination path exists
+		if ([self createUnarchiveDestinationIfNecessary:path] == NO)
+		{
+			return;
+		}
 
 		if ([_tableView selectedRow] == -1)
 		{
@@ -268,6 +327,18 @@
 	}
 }
 
+//- (BOOL)panel:(id)sender isValidFilename:(NSString *)filename
+//{
+//	NSLog(@"panel:isValidFilename: %@", filename);
+//	return YES;
+//}
+//
+//- (NSString *)panel:(id)sender userEnteredFilename:(NSString *)filename confirmed:(BOOL)okFlag
+//{
+//	NSLog(@"userEnteredFilename: %@", filename);
+//	return filename;
+//}
+
 //------------------------------------------------------------------------------
 // private API
 //------------------------------------------------------------------------------
@@ -282,7 +353,7 @@
 		ratioColumn = [_tableView tableColumnWithIdentifier:COL_ID_RATIO];
 		if (ratioColumn == nil)
 		{
-			ratioColumn = [[[NSTableColumn alloc] initWithIdentifier:COL_ID_RATIO] autorelease];
+			ratioColumn = [[(NSTableColumn *)[NSTableColumn alloc] initWithIdentifier:COL_ID_RATIO] autorelease];
 			[[ratioColumn headerCell] setStringValue:@"Ratio"];
 			[ratioColumn setWidth:50.0];
 			[[ratioColumn dataCell] setAlignment:NSRightTextAlignment];
@@ -379,4 +450,30 @@
 	}
 }
 
+- (BOOL)createUnarchiveDestinationIfNecessary:(NSString *)path
+{
+	BOOL isDir, dirExists;
+	
+	dirExists = [[NSFileManager defaultManager] fileExistsAtPath:path isDirectory:&isDir];
+	
+	if (dirExists == NO)
+	{
+		int rc;
+		
+		rc = NSRunAlertPanel(@"Nonexisting destination", 
+			@"The directory '%@' does not exist, do you want to create it?", @"Yes", @"No", nil,
+			path);
+		if (rc == NS_ALERTDEFAULT)
+		{
+			[[NSFileManager defaultManager] createDirectoryPathWithParents:path];
+		}
+		else
+		{
+			return NO;
+		}
+	}
+		
+	return YES;
+}
+
 @end
