@@ -42,4 +42,4 @@ tar czf $releaseName Zipper
 mv $releaseName $workdir/Site
 
 # clean up
-#rm -r $tempdir
+rm -rf $tempdir
